% Auto-generated chapter 15 for tirmidhi
% Hadiths in this chapter: 64

\hadithdefcmd{tirmidhi}{1322}{\hadithno{1322}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif}\hadithtrans{}}
\hadithdefcmd{tirmidhi}{1323}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا وَكِيعٌ، عَنْ إِسْرَائِيلَ، عَنْ عَبْدِ الأَعْلَى، عَنْ بِلاَلِ بْنِ أَبِي مُوسَى، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ سَأَلَ الْقَضَاءَ وُكِلَ إِلَى نَفْسِهِ وَمَنْ أُجْبِرَ عَلَيْهِ يُنْزِلُ اللَّهُ عَلَيْهِ مَلَكًا فَيُسَدِّدُهُ ‏"‏ ‏.‏\hadithno{1323}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Anas bin Malik narrated that the Messenger of Allah (sallAllahu Alayhi wa sallam) said:"Whoever asks for a position as a judge, then he left on his own. And whoever is forced onto it, Allah sends an angel down to him so that he can be correct." (Daif)}}
\hadithdefcmd{tirmidhi}{1324}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ، أَخْبَرَنَا يَحْيَى بْنُ حَمَّادٍ، عَنْ أَبِي عَوَانَةَ، عَنْ عَبْدِ الأَعْلَى الثَّعْلَبِيِّ، عَنْ بِلاَلِ بْنِ مِرْدَاسٍ الْفَزَارِيِّ، عَنْ خَيْثَمَةَ، وَهُوَ الْبَصْرِيُّ عَنْ أَنَسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنِ ابْتَغَى الْقَضَاءَ وَسَأَلَ فِيهِ شُفَعَاءَ وُكِلَ إِلَى نَفْسِهِ وَمَنْ أُكْرِهَ عَلَيْهِ أَنْزَلَ اللَّهُ عَلَيْهِ مَلَكًا يُسَدِّدُهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ وَهُوَ أَصَحُّ مِنْ حَدِيثِ إِسْرَائِيلَ عَنْ عَبْدِ الأَعْلَى ‏.‏\hadithno{1324}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Anas narrated that the Prophet (ﷺ) said:"Whoever seeks to be a judge, and asks others to intercede for him with it, then he will be left on his own. And whoever is coerced into it, Allah sends an angel down to him so that he can be correct." (Daif)}}
\hadithdefcmd{tirmidhi}{1325}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا الْفُضَيْلُ بْنُ سُلَيْمَانَ، عَنْ عَمْرِو بْنِ أَبِي عَمْرٍو، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ وَلِيَ الْقَضَاءَ أَوْ جُعِلَ قَاضِيًا بَيْنَ النَّاسِ فَقَدْ ذُبِحَ بِغَيْرِ سِكِّينٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ وَقَدْ رُوِيَ أَيْضًا مِنْ غَيْرِ هَذَا الْوَجْهِ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{1325}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah (ﷺ) said:"Whoever takes the responsibility of judge, or is appointed as judge between the people, then he has been slaughtered without a knife}}
\hadithdefcmd{tirmidhi}{1326}{حَدَّثَنَا الْحُسَيْنُ بْنُ مَهْدِيٍّ الْبَصْرِيُّ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ سُفْيَانَ الثَّوْرِيِّ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ أَبِي بَكْرِ بْنِ مُحَمَّدِ بْنِ عَمْرِو بْنِ حَزْمٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا حَكَمَ الْحَاكِمُ فَاجْتَهَدَ فَأَصَابَ فَلَهُ أَجْرَانِ وَإِذَا حَكَمَ فَأَخْطَأَ فَلَهُ أَجْرٌ وَاحِدٌ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَمْرِو بْنِ الْعَاصِي وَعُقْبَةَ بْنِ عَامِرٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ لاَ نَعْرِفُهُ مِنْ حَدِيثِ سُفْيَانَ الثَّوْرِيِّ عَنْ يَحْيَى بْنِ سَعِيدٍ إِلاَّ مِنْ حَدِيثِ عَبْدِ الرَّزَّاقِ عَنْ مَعْمَرٍ عَنْ سُفْيَانَ الثَّوْرِيِّ ‏.‏\hadithno{1326}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah (ﷺ) said:"When the judge passes a judgement in which he strived and was correct, then he receives two rewards. And when he judges and is mistaken, then he receives one reward}}
\hadithdefcmd{tirmidhi}{1327}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا وَكِيعٌ، عَنْ شُعْبَةَ، عَنْ أَبِي عَوْنٍ الثَّقَفِيِّ، عَنِ الْحَارِثِ بْنِ عَمْرٍو، عَنْ رِجَالٍ، مِنْ أَصْحَابِ مُعَاذٍ عَنْ مُعَاذٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم بَعَثَ مُعَاذًا إِلَى الْيَمَنِ فَقَالَ ‏"‏ كَيْفَ تَقْضِي ‏"‏ ‏.‏ فَقَالَ أَقْضِي بِمَا فِي كِتَابِ اللَّهِ ‏.‏ قَالَ ‏"‏ فَإِنْ لَمْ يَكُنْ فِي كِتَابِ اللَّهِ ‏"‏ ‏.‏ قَالَ فَبِسُنَّةِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ ‏"‏ فَإِنْ لَمْ يَكُنْ فِي سُنَّةِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏"‏ ‏.‏ قَالَ أَجْتَهِدُ رَأْيِي ‏.‏ قَالَ ‏"‏ الْحَمْدُ لِلَّهِ الَّذِي وَفَّقَ رَسُولَ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏"‏ ‏.‏\hadithno{1327}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Some men who were companions of Mu'adh narrated from Mu'adh that the Messenger of Allah (ﷺ) sent Mu'adh to Yemen, so he (ﷺ) said:"How will you judge?" He said: "I will judge according to what is in Allah's Book." He said: "If it is not in Allah's Book ?" He said: "Then with the Sunnah of the Messenger of Allah (ﷺ)." He said: "If it is not in the Sunnah of Messenger of Allah (ﷺ)?" He said: "I will give in my view." He said: "All praise is due to Allah, the One Who made the messenger of the Messenger of Allah suitable}}
\hadithdefcmd{tirmidhi}{1328}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، وَعَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، قَالاَ حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي عَوْنٍ، عَنِ الْحَارِثِ بْنِ عَمْرٍو ابْنُ أَخٍ، لِلْمُغِيرَةِ بْنِ شُعْبَةَ عَنْ أُنَاسٍ، مِنْ أَهْلِ حِمْصٍ عَنْ مُعَاذٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ وَلَيْسَ إِسْنَادُهُ عِنْدِي بِمُتَّصِلٍ ‏.‏ وَأَبُو عَوْنٍ الثَّقَفِيُّ اسْمُهُ مُحَمَّدُ بْنُ عُبَيْدِ اللَّهِ ‏.‏\hadithno{1328}\hadithgrade{Zubair Ali Zai: Daif}\hadithtrans{(Another chain of narrators) from some people from the inhabitants of Hims, from Mu'adh, from the Prophet (ﷺ), with similar}}
\hadithdefcmd{tirmidhi}{1329}{حَدَّثَنَا عَلِيُّ بْنُ الْمُنْذِرِ الْكُوفِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنْ فُضَيْلِ بْنِ مَرْزُوقٍ، عَنْ عَطِيَّةَ، عَنْ أَبِي سَعِيدٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ أَحَبَّ النَّاسِ إِلَى اللَّهِ يَوْمَ الْقِيَامَةِ وَأَدْنَاهُمْ مِنْهُ مَجْلِسًا إِمَامٌ عَادِلٌ وَأَبْغَضَ النَّاسِ إِلَى اللَّهِ وَأَبْعَدَهُمْ مِنْهُ مَجْلِسًا إِمَامٌ جَائِرٌ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ أَبِي أَوْفَى ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي سَعِيدٍ حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{1329}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Sa'eed narrated that the Messenger of Allah (ﷺ) said:"Indeed, the most beloved of people to Allah on the Day of Judgement, and the nearest to Him in the status is the just Imam. And the most hated of people to Allah and the furthest from Him in status is the oppressive Imam}}
\hadithdefcmd{tirmidhi}{1330}{حَدَّثَنَا عَبْدُ الْقُدُّوسِ بْنُ مُحَمَّدٍ أَبُو بَكْرٍ الْعَطَّارُ، حَدَّثَنَا عَمْرُو بْنُ عَاصِمٍ، حَدَّثَنَا عِمْرَانُ الْقَطَّانُ، عَنْ أَبِي إِسْحَاقَ الشَّيْبَانِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي أَوْفَى، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ مَعَ الْقَاضِي مَا لَمْ يَجُرْ فَإِذَا جَارَ تَخَلَّى عَنْهُ وَلَزِمَهُ الشَّيْطَانُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ عِمْرَانَ الْقَطَّانِ ‏.‏\hadithno{1330}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{[Abdullah] Ibn Abi Al-Awfa narrated that the Messenger of Allah (ﷺ) said:"[Indeed] Allah is with the judge as long as he is not unjust. So when he is unjust, He leaves him and he is attended by Shaitan}}
\hadithdefcmd{tirmidhi}{1331}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا حُسَيْنٌ الْجُعْفِيُّ، عَنْ زَائِدَةَ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ حَنَشٍ، عَنْ عَلِيٍّ، قَالَ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا تَقَاضَى إِلَيْكَ رَجُلاَنِ فَلاَ تَقْضِ لِلأَوَّلِ حَتَّى تَسْمَعَ كَلاَمَ الآخَرِ فَسَوْفَ تَدْرِي كَيْفَ تَقْضِي ‏"‏ ‏.‏ قَالَ عَلِيٌّ فَمَا زِلْتُ قَاضِيًا بَعْدُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏\hadithno{1331}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Ali narrated:"The Messenger of Allah (ﷺ) said to me: 'When two men come to you seeking judgement, do not judge for the first until you have heard the statement of the other. Soon you will know how to judge.'" 'Ali said: "I did not err since then}}
\hadithdefcmd{tirmidhi}{1332}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، حَدَّثَنِي عَلِيُّ بْنُ الْحَكَمِ، حَدَّثَنِي أَبُو الْحَسَنِ، قَالَ قَالَ عَمْرُو بْنُ مُرَّةَ لِمُعَاوِيَةَ إِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَا مِنْ إِمَامٍ يُغْلِقُ بَابَهُ دُونَ ذَوِي الْحَاجَةِ وَالْخَلَّةِ وَالْمَسْكَنَةِ إِلاَّ أَغْلَقَ اللَّهُ أَبْوَابَ السَّمَاءِ دُونَ خَلَّتِهِ وَحَاجَتِهِ وَمَسْكَنَتِهِ ‏"‏ ‏.‏ فَجَعَلَ مُعَاوِيَةُ رَجُلاً عَلَى حَوَائِجِ النَّاسِ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَمْرِو بْنِ مُرَّةَ حَدِيثٌ غَرِيبٌ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ مِنْ غَيْرِ هَذَا الْوَجْهِ ‏.‏ وَعَمْرُو بْنُ مُرَّةَ الْجُهَنِيُّ يُكْنَى أَبَا مَرْيَمَ ‏.‏\hadithno{1332}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Abul-Hasan narrated that 'Amr bin Murrah said to Mu'awiyah:"I heard the Messenger of Allah (ﷺ) saying: 'No Imam closes his door on one in need, dire straits and poverty, except that Allah closes the gates of the Heavens from his dire straits, his needs, and his poverty.' So Mu'awiyah appointed a man to look after the needs of the people}}
\hadithdefcmd{tirmidhi}{1333}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، حَدَّثَنَا يَحْيَى بْنُ حَمْزَةَ، عَنْ يَزِيدَ بْنِ أَبِي مَرْيَمَ، عَنِ الْقَاسِمِ بْنِ مُخَيْمِرَةَ، عَنْ أَبِي مَرْيَمَ، صَاحِبِ رَسُولِ اللَّهِ صلى الله عليه وسلم عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَ هَذَا الْحَدِيثِ بِمَعْنَاهُ ‏.‏ وَيَزِيدُ بْنُ أَبِي مَرْيَمَ شَامِيٌّ وَبُرَيْدُ بْنُ أَبِي مَرْيَمَ كُوفِيٌّ وَأَبُو مَرْيَمَ هُوَ عَمْرُو بْنُ مُرَّةَ الْجُهَنِيُّ ‏.‏\hadithno{1333}\hadithgrade{Zubair Ali Zai: Isnaad Hasan}\hadithtrans{(Another chain) from Abu Maryam the Companion of the Prophet (ﷺ), from the Prophet (ﷺ)}}
\hadithdefcmd{tirmidhi}{1334}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرَةَ، قَالَ كَتَبَ أَبِي إِلَى عُبَيْدِ اللَّهِ بْنِ أَبِي بَكْرَةَ وَهُوَ قَاضٍ أَنْ لاَ، تَحْكُمْ بَيْنَ اثْنَيْنِ وَأَنْتَ غَضْبَانُ ‏.‏ فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ يَحْكُمُ الْحَاكِمُ بَيْنَ اثْنَيْنِ وَهُوَ غَضْبَانُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَأَبُو بَكْرَةَ اسْمُهُ نُفَيْعٌ ‏.‏\hadithno{1334}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abdur-Rahman bin Abi Bakrah narrated:"My father wrote to 'Ubaidullah bin Abi Bakrah who was a judge: "Do not pass a judgement between two people while you are angry, for indeed I heard the Messenger of Allah (ﷺ) saying: 'The judge should not judge between two people while he is angry}}
\hadithdefcmd{tirmidhi}{1335}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ دَاوُدَ بْنِ يَزِيدَ الأَوْدِيِّ، عَنِ الْمُغِيرَةِ بْنِ شُبَيْلٍ، عَنْ قَيْسِ بْنِ أَبِي حَازِمٍ، عَنْ مُعَاذِ بْنِ جَبَلٍ، قَالَ بَعَثَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى الْيَمَنِ فَلَمَّا سِرْتُ أَرْسَلَ فِي أَثَرِي فَرُدِدْتُ فَقَالَ ‏ "‏ أَتَدْرِي لِمَ بَعَثْتُ إِلَيْكَ لاَ تُصِيبَنَّ شَيْئًا بِغَيْرِ إِذْنِي فَإِنَّهُ غُلُولٌ وَمَنْ يَغْلُلْ يَأْتِ بِمَا غَلَّ يَوْمَ الْقِيَامَةِ لِهَذَا دَعَوْتُكَ فَامْضِ لِعَمَلِكَ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَدِيِّ بْنِ عَمِيرَةَ وَبُرَيْدَةَ وَالْمُسْتَوْرِدِ بْنِ شَدَّادٍ وَأَبِي حُمَيْدٍ وَابْنِ عُمَرَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ مُعَاذٍ حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ مِنْ حَدِيثِ أَبِي أُسَامَةَ عَنْ دَاوُدَ الأَوْدِيِّ ‏.‏\hadithno{1335}\hadithgrade{Ahmad Muhammad Shakir: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Mu'adh bin Jabal narrated:"The Messenger of Allah (ﷺ) dispatched me to Yemen. When I had left, he sent a message after me, so I returned and he said: 'Do you know why I sent a message to you ? Do not take anything without my permission, for that will be Ghulul, and whoever commits Ghulul, he comes with what he took on the Day of Judgement. This is why I called you, so now go and do your job}}
\hadithdefcmd{tirmidhi}{1336}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ عُمَرَ بْنِ أَبِي سَلَمَةَ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ لَعَنَ رَسُولُ اللَّهِ صلى الله عليه وسلم الرَّاشِي وَالْمُرْتَشِي فِي الْحُكْمِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو وَعَائِشَةَ وَابْنِ حَدِيدَةَ وَأُمِّ سَلَمَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَرُوِيَ عَنْ أَبِي سَلَمَةَ عَنْ أَبِيهِ عَنِ النَّبِيِّ صلى الله عليه وسلم وَلاَ يَصِحُّ ‏.‏ قَالَ وَسَمِعْتُ عَبْدَ اللَّهِ بْنَ عَبْدِ الرَّحْمَنِ يَقُولُ حَدِيثُ أَبِي سَلَمَةَ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو عَنِ النَّبِيِّ صلى الله عليه وسلم أَحْسَنُ شَيْءٍ فِي هَذَا الْبَابِ وَأَصَحُّ ‏.‏\hadithno{1336}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Hurairah narrated:"The Messenger of Allah (ﷺ) cursed the one who bribes and the one who takes a bribe for a judgement}}
\hadithdefcmd{tirmidhi}{1337}{حَدَّثَنَا أَبُو مُوسَى، مُحَمَّدُ بْنُ الْمُثَنَّى حَدَّثَنَا أَبُو عَامِرٍ الْعَقَدِيُّ، حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، عَنْ خَالِهِ الْحَارِثِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي سَلَمَةَ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ لَعَنَ رَسُولُ اللَّهِ صلى الله عليه وسلم الرَّاشِي وَالْمُرْتَشِي ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1337}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abdullah bin 'Amr narrated:"The Messenger of Allah (ﷺ) cursed the one who bribes and the one who takes a bribe}}
\hadithdefcmd{tirmidhi}{1338}{حَدَّثَنَا أَبُو بَكْرٍ، مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ بَزِيعٍ حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَوْ أُهْدِيَ إِلَىَّ كُرَاعٌ لَقَبِلْتُ وَلَوْ دُعِيتُ عَلَيْهِ لأَجَبْتُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَلِيٍّ وَعَائِشَةَ وَالْمُغِيرَةِ بْنِ شُعْبَةَ وَسَلْمَانَ وَمُعَاوِيَةَ بْنِ حَيْدَةَ وَعَبْدِ الرَّحْمَنِ بْنِ عَلْقَمَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَنَسٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1338}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Anas bin Malik narrated that Messenger of Allah (ﷺ) said:"If trotter (lacking meat) were given to me I would accept it, and if I was invited to (a meal of) it I would accept}}
\hadithdefcmd{tirmidhi}{1339}{حَدَّثَنَا هَارُونُ بْنُ إِسْحَاقَ الْهَمْدَانِيُّ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ زَيْنَبَ بِنْتِ أُمِّ سَلَمَةَ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّكُمْ تَخْتَصِمُونَ إِلَىَّ وَإِنَّمَا أَنَا بَشَرٌ وَلَعَلَّ بَعْضَكُمْ أَنْ يَكُونَ أَلْحَنَ بِحُجَّتِهِ مِنْ بَعْضٍ فَإِنْ قَضَيْتُ لأَحَدٍ مِنْكُمْ بِشَيْءٍ مِنْ حَقِّ أَخِيهِ فَإِنَّمَا أَقْطَعُ لَهُ قِطْعَةً مِنَ النَّارِ فَلاَ يَأْخُذْ مِنْهُ شَيْئًا ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَعَائِشَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أُمِّ سَلَمَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1339}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Umm Salamah narrated that the Messenger of Allah (ﷺ) said:"Indeed you come to me with your disputes, and I am only a human being, perhaps one of you is more eloquent at presenting his argument than the other. If I judge for one of you, giving him something from the rights of his brother, then it is only a piece of the Fire that I am giving him, so do not take anything from it}}
\hadithdefcmd{tirmidhi}{1340}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ عَلْقَمَةَ بْنِ وَائِلِ بْنِ حُجْرٍ، عَنْ أَبِيهِ، قَالَ جَاءَ رَجُلٌ مِنْ حَضْرَمَوْتَ وَرَجُلٌ مِنْ كِنْدَةَ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ الْحَضْرَمِيُّ يَا رَسُولَ اللَّهِ إِنَّ هَذَا غَلَبَنِي عَلَى أَرْضٍ لِي ‏.‏ فَقَالَ الْكِنْدِيُّ هِيَ أَرْضِي وَفِي يَدِي لَيْسَ لَهُ فِيهَا حَقٌّ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم لِلْحَضْرَمِيِّ ‏"‏ أَلَكَ بَيِّنَةٌ ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ فَلَكَ يَمِينُهُ ‏"‏ ‏.‏ قَالَ يَا رَسُولَ اللَّهِ إِنَّ الرَّجُلَ فَاجِرٌ لاَ يُبَالِي عَلَى مَا حَلَفَ عَلَيْهِ وَلَيْسَ يَتَوَرَّعُ مِنْ شَيْءٍ ‏.‏ قَالَ ‏"‏ لَيْسَ لَكَ مِنْهُ إِلاَّ ذَلِكَ ‏"‏ ‏.‏ قَالَ فَانْطَلَقَ الرَّجُلُ لِيَحْلِفَ لَهُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لَمَّا أَدْبَرَ ‏"‏ لَئِنْ حَلَفَ عَلَى مَالِكَ لِيَأْكُلَهُ ظُلْمًا لَيَلْقَيَنَّ اللَّهَ وَهُوَ عَنْهُ مُعْرِضٌ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عُمَرَ وَابْنِ عَبَّاسٍ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو وَالأَشْعَثِ بْنِ قَيْسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ وَائِلِ بْنِ حُجْرٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1340}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Alqamah bin Wa'il [bin Hujr] narrated from his father who said:"A man from Hadramawt and a man from Kindah came to the Prophet (ﷺ). The Hadrami said: 'O Messenger of Allah! This person took some land of mine.' The Kindi said:'It is my land, It is in my possession, and he has no right to it.' So the Prophet (ﷺ) said to the Hadrami:'Do you have proof?' He said: 'No.' He said: 'Then you will have the oath.' He said: 'O Messenger of Allah! This man is a liar, it makes not difference what he takes an oath for, he is not ashamed of doing anything!' He said: 'There is nothing you deserve from him except that.' He said: So the man was left to take an oath for it, and in the meantime, the Messenger of Allah (ﷺ) said: 'If he takes an oath [for your property] to wrongfully consume it, He will meet Allah while He is angry with him}}
\hadithdefcmd{tirmidhi}{1341}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَنْبَأَنَا عَلِيُّ بْنُ مُسْهِرٍ، وَغَيْرُهُ، عَنْ مُحَمَّدِ بْنِ عُبَيْدِ اللَّهِ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ فِي خُطْبَتِهِ ‏ "‏ الْبَيِّنَةُ عَلَى الْمُدَّعِي وَالْيَمِينُ عَلَى الْمُدَّعَى عَلَيْهِ ‏"‏ ‏.‏ هَذَا حَدِيثٌ فِي إِسْنَادِهِ مَقَالٌ ‏.‏ وَمُحَمَّدُ بْنُ عُبَيْدِ اللَّهِ الْعَرْزَمِيُّ يُضَعَّفُ فِي الْحَدِيثِ مِنْ قِبَلِ حِفْظِهِ ضَعَّفَهُ ابْنُ الْمُبَارَكِ وَغَيْرُهُ ‏.‏\hadithno{1341}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Amr bin Shu'aib narrated from his father, from his grandfather, that during a Khutbah, the Prophet (ﷺ) said:"The proof is due from the claimant, and the oath is due from the one the claim is made against}}
\hadithdefcmd{tirmidhi}{1342}{حَدَّثَنَا مُحَمَّدُ بْنُ سَهْلِ بْنِ عَسْكَرٍ الْبَغْدَادِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا نَافِعُ بْنُ عُمَرَ الْجُمَحِيُّ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي مُلَيْكَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَضَى أَنَّ الْيَمِينَ عَلَى الْمُدَّعَى عَلَيْهِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ أَنَّ الْبَيِّنَةَ عَلَى الْمُدَّعِي وَالْيَمِينَ عَلَى الْمُدَّعَى عَلَيْهِ ‏.‏\hadithno{1342}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ibn 'Abbas narrated that the Messenger of Allah (ﷺ) judged that the oath is due from the one the claim is made against}}
\hadithdefcmd{tirmidhi}{1343}{حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ الدَّوْرَقِيُّ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنِي رَبِيعَةُ بْنُ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَضَى رَسُولُ اللَّهِ صلى الله عليه وسلم بِالْيَمِينِ مَعَ الشَّاهِدِ الْوَاحِدِ ‏.‏ قَالَ رَبِيعَةُ وَأَخْبَرَنِي ابْنٌ لِسَعْدِ بْنِ عُبَادَةَ قَالَ وَجَدْنَا فِي كِتَابِ سَعْدٍ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَضَى بِالْيَمِينِ مَعَ الشَّاهِدِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَلِيٍّ وَجَابِرٍ وَابْنِ عَبَّاسٍ وَسُرَّقَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَضَى بِالْيَمِينِ مَعَ الشَّاهِدِ الْوَاحِدِ حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{1343}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Hurairah narrated:"The Messenger of Allah (ﷺ) passed judgement based on an oath along with one witness." Rabi'ah (one of the narrators) said: "A son of Ibn Sa'd bin 'Ubadah informed me saying: 'We found in a book of Sa'd that the Prophet (ﷺ) passed judgement based on an oath along with a witness}}
\hadithdefcmd{tirmidhi}{1344}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، وَمُحَمَّدُ بْنُ أَبَانَ، قَالاَ حَدَّثَنَا عَبْدُ الْوَهَّابِ الثَّقَفِيُّ، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ جَابِرٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَضَى بِالْيَمِينِ مَعَ الشَّاهِدِ ‏.‏\hadithno{1344}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Jabir narrated:"The Prophet (ﷺ) passed judgement based on oath along with a witness}}
\hadithdefcmd{tirmidhi}{1345}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، حَدَّثَنَا جَعْفَرُ بْنُ مُحَمَّدٍ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَضَى بِالْيَمِينِ مَعَ الشَّاهِدِ الْوَاحِدِ ‏.‏ قَالَ وَقَضَى بِهَا عَلِيٌّ فِيكُمْ ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا أَصَحُّ وَهَكَذَا رَوَى سُفْيَانُ الثَّوْرِيُّ عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ عَنْ أَبِيهِ عَنِ النَّبِيِّ صلى الله عليه وسلم مُرْسَلاً ‏.‏ وَرَوَى عَبْدُ الْعَزِيزِ بْنُ أَبِي سَلَمَةَ وَيَحْيَى بْنُ سُلَيْمٍ هَذَا الْحَدِيثَ عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ عَنْ أَبِيهِ عَنْ عَلِيٍّ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ رَأَوْا أَنَّ الْيَمِينَ مَعَ الشَّاهِدِ الْوَاحِدِ جَائِزٌ فِي الْحُقُوقِ وَالأَمْوَالِ ‏.‏ وَهُوَ قَوْلُ مَالِكِ بْنِ أَنَسٍ وَالشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ وَقَالُوا لاَ يُقْضَى بِالْيَمِينِ مَعَ الشَّاهِدِ الْوَاحِدِ إِلاَّ فِي الْحُقُوقِ وَالأَمْوَالِ ‏.‏ وَلَمْ يَرَ بَعْضُ أَهْلِ الْعِلْمِ مِنْ أَهْلِ الْكُوفَةِ وَغَيْرِهِمْ أَنْ يُقْضَى بِالْيَمِينِ مَعَ الشَّاهِدِ الْوَاحِدِ ‏.‏\hadithno{1345}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ja'far bin Muhammad narrated from his father:"The Prophet (ﷺ) passed judgement based on an oath along with one witness." He said: "And 'Ali judged between you based on it}}
\hadithdefcmd{tirmidhi}{1346}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَعْتَقَ نَصِيبًا - أَوْ قَالَ شِقْصًا أَوْ قَالَ شِرْكًا لَهُ فِي عَبْدٍ فَكَانَ لَهُ مِنَ الْمَالِ مَا يَبْلُغُ ثَمَنَهُ بِقِيمَةِ الْعَدْلِ فَهُوَ عَتِيقٌ وَإِلاَّ فَقَدْ عَتَقَ مِنْهُ مَا عَتَقَ ‏"‏ ‏.‏ قَالَ أَيُّوبُ وَرُبَّمَا قَالَ نَافِعٌ فِي هَذَا الْحَدِيثِ يَعْنِي فَقَدْ عَتَقَ مِنْهُ مَا عَتَقَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عُمَرَ حَدِيثٌ حَسَنٌ صَحِيحٌ وَقَدْ رَوَاهُ سَالِمٌ عَنْ أَبِيهِ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏\hadithno{1346}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ibn 'Umar narrated that the Prophet (ﷺ) said:"Whoever frees a portion" or, he said: "a part" or he said: "a share he owns of a slave, then he can afford the remainder of the price according to the reasonable price, then he will be free. Otherwise he has freed as much as he has freed (only)." Ayyub (one of the narrators) said: "Perhaps Nafi said in this Hadith: 'Meaning he has freed as much of him as he has freed}}
\hadithdefcmd{tirmidhi}{1347}{حَدَّثَنَا بِذَلِكَ الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ الْحُلْوَانِيُّ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَعْتَقَ نَصِيبًا لَهُ فِي عَبْدٍ فَكَانَ لَهُ مِنَ الْمَالِ مَا يَبْلُغُ ثَمَنَهُ فَهُوَ عَتِيقٌ مِنْ مَالِهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ صَحِيحٌ ‏.‏\hadithno{1347}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Salim narrated from his father that the Prophet (ﷺ) said:"Whoever frees a portion of a slave he owns, then he can afford the remainder of the price, then he should free him with his wealth}}
\hadithdefcmd{tirmidhi}{1348}{حَدَّثَنَا عَلِيُّ بْنُ خَشْرَمٍ، أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، عَنْ سَعِيدِ بْنِ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، عَنِ النَّضْرِ بْنِ أَنَسٍ، عَنْ بَشِيرِ بْنِ نَهِيكٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ أَعْتَقَ نَصِيبًا - أَوْ قَالَ شِقْصًا فِي مَمْلُوكٍ فَخَلاَصُهُ فِي مَالِهِ إِنْ كَانَ لَهُ مَالٌ فَإِنْ لَمْ يَكُنْ لَهُ مَالٌ قُوِّمَ قِيمَةَ عَدْلٍ ثُمَّ يُسْتَسْعَى فِي نَصِيبِ الَّذِي لَمْ يُعْتِقْ غَيْرَ مَشْقُوقٍ عَلَيْهِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو ‏.‏ حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ سَعِيدِ بْنِ أَبِي عَرُوبَةَ، نَحْوَهُ وَقَالَ ‏"‏ شَقِيصًا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَهَكَذَا رَوَى أَبَانُ بْنُ يَزِيدَ، عَنْ قَتَادَةَ، مِثْلَ رِوَايَةِ سَعِيدِ بْنِ أَبِي عَرُوبَةَ ‏.‏ وَرَوَى شُعْبَةُ، هَذَا الْحَدِيثَ عَنْ قَتَادَةَ، وَلَمْ يَذْكُرْ فِيهِ أَمْرَ السِّعَايَةِ ‏.‏ وَاخْتَلَفَ أَهْلُ الْعِلْمِ فِي السِّعَايَةِ فَرَأَى بَعْضُ أَهْلِ الْعِلْمِ السِّعَايَةَ فِي هَذَا ‏.‏ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَأَهْلِ الْكُوفَةِ وَبِهِ يَقُولُ إِسْحَاقُ ‏.‏ وَقَدْ قَالَ بَعْضُ أَهْلِ الْعِلْمِ إِذَا كَانَ الْعَبْدُ بَيْنَ الرَّجُلَيْنِ فَأَعْتَقَ أَحَدُهُمَا نَصِيبَهُ فَإِنْ كَانَ لَهُ مَالٌ غَرِمَ نَصِيبَ صَاحِبِهِ وَعَتَقَ الْعَبْدَ مِنْ مَالِهِ وَإِنْ لَمْ يَكُنْ لَهُ مَالٌ عَتَقَ مِنَ الْعَبْدِ مَا عَتَقَ وَلاَ يُسْتَسْعَى ‏.‏ وَقَالُوا بِمَا رُوِيَ عَنِ ابْنِ عُمَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَهَذَا قَوْلُ أَهْلِ الْمَدِينَةِ وَبِهِ يَقُولُ مَالِكُ بْنُ أَنَسٍ وَالشَّافِعِيُّ وَأَحْمَدُ ‏.‏\hadithno{1348}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah (ﷺ) said:"Whoever frees a portion" or he said: "a part of a slave, then he should finish paying his price if he can afford it. If he can not afford to pay reasonable price then he should be allowed to work to earn the amount that will free him without overburdening him." (Another chain) similar, and he said: "a part}}
\hadithdefcmd{tirmidhi}{1349}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ سَمُرَةَ، أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْعُمْرَى جَائِزَةٌ لأَهْلِهَا أَوْ مِيرَاثٌ لأَهْلِهَا ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ زَيْدِ بْنِ ثَابِتٍ وَجَابِرٍ وَأَبِي هُرَيْرَةَ وَعَائِشَةَ وَابْنِ الزُّبَيْرِ وَمُعَاوِيَةَ ‏.‏\hadithno{1349}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Samurah narrated that the Prophet (ﷺ) said:"The lifelong gift is permitted for its inhabitant" or:"is an inheritance for its inhabitant}}
\hadithdefcmd{tirmidhi}{1350}{حَدَّثَنَا الأَنْصَارِيُّ، حَدَّثَنَا مَعْنٌ، حَدَّثَنَا مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ، عَنْ جَابِرٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ أَيُّمَا رَجُلٍ أُعْمِرَ عُمْرَى لَهُ وَلِعَقِبِهِ فَإِنَّهَا لِلَّذِي يُعْطَاهَا لاَ تَرْجِعُ إِلَى الَّذِي أَعْطَاهَا لأَنَّهُ أَعْطَى عَطَاءً وَقَعَتْ فِيهِ الْمَوَارِيثُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَهَكَذَا رَوَى مَعْمَرٌ وَغَيْرُ وَاحِدٍ عَنِ الزُّهْرِيِّ مِثْلَ رِوَايَةِ مَالِكٍ ‏.‏ وَرَوَى بَعْضُهُمْ عَنِ الزُّهْرِيِّ وَلَمْ يَذْكُرْ فِيهِ ‏"‏ وَلِعَقِبِهِ ‏"‏ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ قَالُوا إِذَا قَالَ هِيَ لَكَ حَيَاتَكَ وَلِعَقِبِكَ ‏.‏ فَإِنَّهَا لِمَنْ أُعْمِرَهَا لاَ تَرْجِعُ إِلَى الأَوَّلِ ‏.‏ وَإِذَا لَمْ يَقُلْ لِعَقِبِكَ فَهِيَ رَاجِعَةٌ إِلَى الأَوَّلِ إِذَا مَاتَ الْمُعْمَرُ ‏.‏ وَهُوَ قَوْلُ مَالِكِ بْنِ أَنَسٍ وَالشَّافِعِيِّ ‏.‏ وَرُوِيَ مِنْ غَيْرِ وَجْهٍ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ الْعُمْرَى جَائِزَةٌ لأَهْلِهَا ‏"‏ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ قَالُوا إِذَا مَاتَ الْمُعْمَرُ فَهِيَ لِوَرَثَتِهِ وَإِنْ لَمْ تُجْعَلْ لِعَقِبِهِ ‏.‏ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏\hadithno{1350}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Jabir narrated that the Prophet (ﷺ) said:"Whichever man is given a lifelong gift for himself and his offspring, then it belongs to the one whom it was given, it does not return to the one who gave it, for he has given a gift which shall be included in the inheritance}}
\hadithdefcmd{tirmidhi}{1351}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا هُشَيْمٌ، عَنْ دَاوُدَ بْنِ أَبِي هِنْدٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْعُمْرَى جَائِزَةٌ لأَهْلِهَا وَالرُّقْبَى جَائِزَةٌ لأَهْلِهَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَقَدْ رَوَاهُ بَعْضُهُمْ عَنْ أَبِي الزُّبَيْرِ بِهَذَا الإِسْنَادِ عَنْ جَابِرٍ مَوْقُوفًا وَلَمْ يَرْفَعْهُ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ أَنَّ الرُّقْبَى جَائِزَةٌ مِثْلَ الْعُمْرَى ‏.‏ وَهُوَ قَوْلُ أَحْمَدَ وَإِسْحَاقَ ‏.‏ وَفَرَّقَ بَعْضُ أَهْلِ الْعِلْمِ مِنْ أَهْلِ الْكُوفَةِ وَغَيْرِهِمْ بَيْنَ الْعُمْرَى وَالرُّقْبَى فَأَجَازُوا الْعُمْرَى وَلَمْ يُجِيزُوا الرُّقْبَى ‏.‏ قَالَ أَبُو عِيسَى وَتَفْسِيرُ الرُّقْبَى أَنْ يَقُولَ هَذَا الشَّىْءُ لَكَ مَا عِشْتَ فَإِنْ مِتَّ قَبْلِي فَهِيَ رَاجِعَةٌ إِلَىَّ ‏.‏ وَقَالَ أَحْمَدُ وَإِسْحَاقُ الرُّقْبَى مِثْلُ الْعُمْرَى وَهِيَ لِمَنْ أُعْطِيَهَا وَلاَ تَرْجِعُ إِلَى الأَوَّلِ ‏.‏\hadithno{1351}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Jabir narrated that the Messenger of Allah (ﷺ) said:"The lifelong gift is permitted for its inhabitant, and the Ruqba is permitted for its inhabitant}}
\hadithdefcmd{tirmidhi}{1352}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، حَدَّثَنَا أَبُو عَامِرٍ الْعَقَدِيُّ، حَدَّثَنَا كَثِيرُ بْنُ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ عَوْفٍ الْمُزَنِيُّ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الصُّلْحُ جَائِزٌ بَيْنَ الْمُسْلِمِينَ إِلاَّ صُلْحًا حَرَّمَ حَلاَلاً أَوْ أَحَلَّ حَرَامًا وَالْمُسْلِمُونَ عَلَى شُرُوطِهِمْ إِلاَّ شَرْطًا حَرَّمَ حَلاَلاً أَوْ أَحَلَّ حَرَامًا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1352}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Kathir bin 'Amr bin 'Awf Al-Muzani narrated from his father, from his grandfather, that the Messenger of Allah (ﷺ) said:"Reconciliation is allowed among the Muslims, except for reconciliation that makes the lawful unlawful, or the unlawful lawful. And the Muslims will be held to their conditions, except the conditions that make the lawful unlawful, or the unlawful lawful}}
\hadithdefcmd{tirmidhi}{1353}{حَدَّثَنَا سَعِيدُ بْنُ عَبْدِ الرَّحْمَنِ الْمَخْزُومِيُّ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ سَمِعْتُهُ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا اسْتَأْذَنَ أَحَدَكُمْ جَارُهُ أَنْ يَغْرِزَ خَشَبَةً فِي جِدَارِهِ فَلاَ يَمْنَعْهُ ‏"‏ ‏.‏ فَلَمَّا حَدَّثَ أَبُو هُرَيْرَةَ طَأْطَئُوا رُءُوسَهُمْ فَقَالَ مَا لِي أَرَاكُمْ عَنْهَا مُعْرِضِينَ وَاللَّهِ لأَرْمِيَنَّ بِهَا بَيْنَ أَكْتَافِكُمْ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عَبَّاسٍ وَمُجَمِّعِ بْنِ جَارِيَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ وَبِهِ يَقُولُ الشَّافِعِيُّ ‏.‏ وَرُوِيَ عَنْ بَعْضِ أَهْلِ الْعِلْمِ مِنْهُمْ مَالِكُ بْنُ أَنَسٍ قَالُوا لَهُ أَنْ يَمْنَعَ جَارَهُ أَنْ يَضَعَ خَشَبَهُ فِي جِدَارِهِ ‏.‏ وَالْقَوْلُ الأَوَّلُ أَصَحُّ ‏.‏\hadithno{1353}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Al-A`raj narrated from Abu Hurairah, saying:“I heard him saying: ‘the Messenger of Allah (ﷺ) said: “When one of you seeks his neighbor’s permission to affix a wooden beam in his wall, then do not prevent him."' When Abu Hurairah narrated it, they tilted their heads, so he said: ‘Why do I see that you are averse to it? By Allah! I will continue to narrate it among you}}
\hadithdefcmd{tirmidhi}{1354}{حَدَّثَنَا قُتَيْبَةُ، وَأَحْمَدُ بْنُ مَنِيعٍ، - الْمَعْنَى وَاحِدٌ - قَالاَ حَدَّثَنَا هُشَيْمٌ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ الْيَمِينُ عَلَى مَا يُصَدِّقُكَ بِهِ صَاحِبُكَ ‏"‏ ‏.‏ وَقَالَ قُتَيْبَةُ ‏"‏ عَلَى مَا صَدَّقَكَ عَلَيْهِ صَاحِبُكَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ هُشَيْمٍ عَنْ عَبْدِ اللَّهِ بْنِ أَبِي صَالِحٍ ‏.‏ وَعَبْدُ اللَّهِ بْنُ أَبِي صَالِحٍ هُوَ أَخُو سُهَيْلِ بْنِ أَبِي صَالِحٍ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ وَبِهِ يَقُولُ أَحْمَدُ وَإِسْحَاقُ ‏.‏ وَرُوِيَ عَنْ إِبْرَاهِيمَ النَّخَعِيِّ أَنَّهُ قَالَ إِذَا كَانَ الْمُسْتَحْلِفُ ظَالِمًا فَالنِّيَّةُ نِيَّةُ الْحَالِفِ وَإِذَا كَانَ الْمُسْتَحْلِفُ مَظْلُومًا فَالنِّيَّةُ نِيَّةُ الَّذِي اسْتَحْلَفَ ‏.‏\hadithno{1354}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah (ﷺ) said:“The oath is based upon what will make your companion believe you.” [Qutaibah (one of the narrators) said: “ What will make you believed by your companion”}}
\hadithdefcmd{tirmidhi}{1355}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا وَكِيعٌ، عَنِ الْمُثَنَّى بْنِ سَعِيدٍ الضُّبَعِيِّ، عَنْ قَتَادَةَ، عَنْ بَشِيرِ بْنِ نَهِيكٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اجْعَلُوا الطَّرِيقَ سَبْعَةَ أَذْرُعٍ ‏"‏ ‏.‏\hadithno{1355}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah (ﷺ) said:“Make the road seven forearm lengths.”}}
\hadithdefcmd{tirmidhi}{1356}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، حَدَّثَنَا الْمُثَنَّى بْنُ سَعِيدٍ، عَنْ قَتَادَةَ، عَنْ بُشَيْرِ بْنِ كَعْبٍ الْعَدَوِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا تَشَاجَرْتُمْ فِي الطَّرِيقِ فَاجْعَلُوهُ سَبْعَةَ أَذْرُعٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا أَصَحُّ مِنْ حَدِيثِ وَكِيعٍ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عَبَّاسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ بُشَيْرِ بْنِ كَعْبٍ الْعَدَوِيِّ عَنْ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَرَوَى بَعْضُهُمْ هَذَا عَنْ قَتَادَةَ عَنْ بَشِيرِ بْنِ نَهِيكٍ عَنْ أَبِي هُرَيْرَةَ ‏.‏ وَهُوَ غَيْرُ مَحْفُوظٍ ‏.‏\hadithno{1356}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah (ﷺ) said:"When you disagree over the road, then make it seven forearm lengths}}
\hadithdefcmd{tirmidhi}{1357}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، حَدَّثَنَا سُفْيَانُ، عَنْ زِيَادِ بْنِ سَعْدٍ، عَنْ هِلاَلِ بْنِ أَبِي مَيْمُونَةَ الثَّعْلَبِيِّ، عَنْ أَبِي مَيْمُونَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم خَيَّرَ غُلاَمًا بَيْنَ أَبِيهِ وَأُمِّهِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو وَجَدِّ عَبْدِ الْحَمِيدِ بْنِ جَعْفَرٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَأَبُو مَيْمُونَةَ اسْمُهُ سُلَيْمٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ قَالُوا يُخَيَّرُ الْغُلاَمُ بَيْنَ أَبَوَيْهِ إِذَا وَقَعَتْ بَيْنَهُمَا الْمُنَازَعَةُ فِي الْوَلَدِ ‏.‏ وَهُوَ قَوْلُ أَحْمَدَ وَإِسْحَاقَ وَقَالاَ مَا كَانَ الْوَلَدُ صَغِيرًا فَالأُمُّ أَحَقُّ فَإِذَا بَلَغَ الْغُلاَمُ سَبْعَ سِنِينَ خُيِّرَ بَيْنَ أَبَوَيْهِ ‏.‏ هِلاَلُ بْنُ أَبِي مَيْمُونَةَ هُوَ هِلاَلُ بْنُ عَلِيِّ بْنِ أُسَامَةَ وَهُوَ مَدَنِيٌّ وَقَدْ رَوَى عَنْهُ يَحْيَى بْنُ أَبِي كَثِيرٍ وَمَالِكُ بْنُ أَنَسٍ وَفُلَيْحُ بْنُ سُلَيْمَانَ ‏.‏\hadithno{1357}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Maimunah narrated from Abu Hurairah who said:"The Prophet (ﷺ) gave a boy the choice between his father and his mother}}
\hadithdefcmd{tirmidhi}{1358}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا يَحْيَى بْنُ زَكَرِيَّا بْنِ أَبِي زَائِدَةَ، حَدَّثَنَا الأَعْمَشُ، عَنْ عُمَارَةَ بْنِ عُمَيْرٍ، عَنْ عَمَّتِهِ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ أَطْيَبَ مَا أَكَلْتُمْ مِنْ كَسْبِكُمْ وَإِنَّ أَوْلاَدَكُمْ مِنْ كَسْبِكُمْ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ جَابِرٍ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَقَدْ رَوَى بَعْضُهُمْ هَذَا عَنْ عُمَارَةَ بْنِ عُمَيْرٍ عَنْ أُمِّهِ عَنْ عَائِشَةَ ‏.‏ وَأَكْثَرُهُمْ قَالُوا عَنْ عَمَّتِهِ عَنْ عَائِشَةَ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ قَالُوا إِنَّ يَدَ الْوَالِدِ مَبْسُوطَةٌ فِي مَالِ وَلَدِهِ يَأْخُذُ مَا شَاءَ ‏.‏ وَقَالَ بَعْضُهُمْ لاَ يَأْخُذُ مِنْ مَالِهِ إِلاَّ عِنْدَ الْحَاجَةِ إِلَيْهِ ‏.‏\hadithno{1358}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Aishah narrated that the Messenger of Allah (ﷺ) said:"Indeed the most wholesome of what you consume is from your earnings, and indeed your children are from your earnings}}
\hadithdefcmd{tirmidhi}{1359}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو دَاوُدَ الْحَفَرِيُّ، عَنْ سُفْيَانَ الثَّوْرِيِّ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، قَالَ أَهْدَتْ بَعْضُ أَزْوَاجِ النَّبِيِّ صلى الله عليه وسلم إِلَى النَّبِيِّ صلى الله عليه وسلم طَعَامًا فِي قَصْعَةٍ فَضَرَبَتْ عَائِشَةُ الْقَصْعَةَ بِيَدِهَا فَأَلْقَتْ مَا فِيهَا فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ طَعَامٌ بِطَعَامٍ وَإِنَاءٌ بِإِنَاءٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1359}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Anas narrated:"One of the wives of the Prophet (ﷺ) gave the Prophet (ﷺ) some food in a bowl. Then 'Aishah broke the bowl with her hand, and discarded what was in it. So the Prophet (ﷺ) said: "Food for food and vessel for vessel}}
\hadithdefcmd{tirmidhi}{1360}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا سُوَيْدُ بْنُ عَبْدِ الْعَزِيزِ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم اسْتَعَارَ قَصْعَةً فَضَاعَتْ فَضَمِنَهَا لَهُمْ ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا حَدِيثٌ غَيْرُ مَحْفُوظٍ ‏.‏ وَإِنَّمَا أَرَادَ عِنْدِي سُوَيْدٌ الْحَدِيثَ الَّذِي رَوَاهُ الثَّوْرِيُّ وَحَدِيثُ الثَّوْرِيِّ أَصَحُّ ‏.‏ اسْمُ أَبِي دَاوُدَ عُمَرُ بْنُ سَعْدٍ ‏.‏\hadithno{1360}\hadithgrade{Ahmad Muhammad Shakir: Very Daif Isnaad; Al-Albani: Very Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Anas narrated that the Messenger of Allah (ﷺ) borrowed a bowl which broke, so he guaranteed (compensated) it for them}}
\hadithdefcmd{tirmidhi}{1361}{حَدَّثَنَا مُحَمَّدُ بْنُ وَزِيرٍ الْوَاسِطِيُّ، حَدَّثَنَا إِسْحَاقُ بْنُ يُوسُفَ الأَزْرَقُ، عَنْ سُفْيَانَ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ عُرِضْتُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فِي جَيْشٍ وَأَنَا ابْنُ أَرْبَعَ عَشْرَةَ فَلَمْ يَقْبَلْنِي فَعُرِضْتُ عَلَيْهِ مِنْ قَابِلٍ فِي جَيْشٍ وَأَنَا ابْنُ خَمْسَ عَشْرَةَ فَقَبِلَنِي ‏.‏ قَالَ نَافِعٌ وَحَدَّثْتُ بِهَذَا الْحَدِيثِ عُمَرَ بْنَ عَبْدِ الْعَزِيزِ فَقَالَ هَذَا حَدُّ مَا بَيْنَ الصَّغِيرِ وَالْكَبِيرِ ‏.‏ ثُمَّ كَتَبَ أَنْ يُفْرَضَ لِمَنْ يَبْلُغُ الْخَمْسَ عَشْرَةَ ‏.‏ حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَ هَذَا وَلَمْ يَذْكُرْ فِيهِ أَنَّ عُمَرَ بْنَ عَبْدِ الْعَزِيزِ كَتَبَ أَنَّ هَذَا حَدُّ مَا بَيْنَ الصَّغِيرِ وَالْكَبِيرِ ‏.‏ وَذَكَرَ ابْنُ عُيَيْنَةَ فِي حَدِيثِهِ ‏.‏ قَالَ نَافِعٌ فَحَدَّثْنَا بِهِ عُمَرَ بْنَ عَبْدِ الْعَزِيزِ فَقَالَ هَذَا حَدُّ مَا بَيْنَ الذُّرِّيَّةِ وَالْمُقَاتِلَةِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ وَبِهِ يَقُولُ سُفْيَانُ الثَّوْرِيُّ وَابْنُ الْمُبَارَكِ وَالشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ يَرَوْنَ أَنَّ الْغُلاَمَ إِذَا اسْتَكْمَلَ خَمْسَ عَشْرَةَ سَنَةً فَحُكْمُهُ حُكْمُ الرِّجَالِ وَإِنِ احْتَلَمَ قَبْلَ خَمْسَ عَشْرَةَ فَحُكْمُهُ حُكْمُ الرِّجَالِ ‏.‏ وَقَالَ أَحْمَدُ وَإِسْحَاقُ الْبُلُوغُ ثَلاَثَةُ مَنَازِلَ بُلُوغُ خَمْسَ عَشْرَةَ أَوْ الاِحْتِلاَمُ فَإِنْ لَمْ يُعْرَفْ سِنُّهُ وَلاَ احْتِلاَمُهُ فَالإِنْبَاتُ يَعْنِي الْعَانَةَ ‏.‏\hadithno{1361}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Nafi':that Ibn 'Umar said: "I was reviewed before the Messenger of Allah (ﷺ) in the army, and I was fourteen years old, but he did not accept me. Then I was reviewed before him in the army later while I was fifteen years old, and he accepted me." Nafi' said: "I narrated this Hadith to 'Uman bin 'Abdul Azeez and he said: 'This is the limit that distinguishes between childhood and adulthood.' Then he wrote to give salaries to whoever reached fifteen years old." (Another chain) from Nafi', from Ibn 'Umar from the Prophet (ﷺ) and it is similar, but he did not mention in it that 'Umar bin 'Abdul-'Aziz wrote that this is the limit that distinguishes between youth and childhood and adulthood. In his narration, Ibn 'Uyainah said (that Nafi' said): "I narrated it to 'Umar bin 'Abdul-'Aziz and he said: 'This is the limit that distinguishes between children and soldiers}}
\hadithdefcmd{tirmidhi}{1362}{حَدَّثَنَا أَبُو سَعِيدٍ الأَشَجُّ، حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، عَنْ أَشْعَثَ، عَنْ عَدِيِّ بْنِ ثَابِتٍ، عَنِ الْبَرَاءِ، قَالَ مَرَّ بِي خَالِي أَبُو بُرْدَةَ بْنُ نِيَارٍ وَمَعَهُ لِوَاءٌ فَقُلْتُ أَيْنَ تُرِيدُ قَالَ بَعَثَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى رَجُلٍ تَزَوَّجَ امْرَأَةَ أَبِيهِ أَنْ آتِيَهُ بِرَأْسِهِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ قُرَّةَ الْمُزَنِيِّ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ الْبَرَاءِ حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَقَدْ رَوَى مُحَمَّدُ بْنُ إِسْحَاقَ هَذَا الْحَدِيثَ عَنْ عَدِيِّ بْنِ ثَابِتٍ عَنْ عَبْدِ اللَّهِ بْنِ يَزِيدَ عَنِ الْبَرَاءِ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ عَنْ أَشْعَثَ عَنْ عَدِيٍّ عَنْ يَزِيدَ بْنِ الْبَرَاءِ عَنْ أَبِيهِ وَرُوِيَ عَنْ أَشْعَثَ عَنْ عَدِيٍّ عَنْ يَزِيدَ بْنِ الْبَرَاءِ عَنْ خَالِهِ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{1362}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Al-Bara':"My maternal uncle Abu Burdah Ibn Niyar passed by me and he had a flag with him. I said: 'Where are you going ?' He said: 'the Messenger of Allah (ﷺ) dispatched me to a man who married a woman his father had married to: that I should bring him his head}}
\hadithdefcmd{tirmidhi}{1363}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، أَنَّهُ حَدَّثَهُ أَنَّ عَبْدَ اللَّهِ بْنَ الزُّبَيْرِ حَدَّثَهُ أَنَّ رَجُلاً مِنَ الأَنْصَارِ خَاصَمَ الزُّبَيْرَ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي شِرَاجِ الْحَرَّةِ الَّتِي يَسْقُونَ بِهَا النَّخْلَ فَقَالَ الأَنْصَارِيُّ سَرِّحِ الْمَاءَ يَمُرُّ ‏.‏ فَأَبَى عَلَيْهِ فَاخْتَصَمُوا عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِلزُّبَيْرِ ‏"‏ اسْقِ يَا زُبَيْرُ ثُمَّ أَرْسِلِ الْمَاءَ إِلَى جَارِكَ ‏"‏ ‏.‏ فَغَضِبَ الأَنْصَارِيُّ فَقَالَ يَا رَسُولَ اللَّهِ أَنْ كَانَ ابْنَ عَمَّتِكَ فَتَلَوَّنَ وَجْهُ رَسُولِ اللَّهِ صلى الله عليه وسلم ثُمَّ قَالَ ‏"‏ يَا زُبَيْرُ اسْقِ ثُمَّ احْبِسِ الْمَاءَ حَتَّى يَرْجِعَ إِلَى الْجَدْرِ ‏"‏ ‏.‏ فَقَالَ الزُّبَيْرُ وَاللَّهِ إِنِّي لأَحْسِبُ نَزَلَتْ هَذِهِ الآيَةُ فِي ذَلِكَ ‏:‏ ‏(‏فَلاَ وَرَبِّكَ لاَ يُؤْمِنُونَ حَتَّى يُحَكِّمُوكَ فِيمَا شَجَرَ بَيْنَهُمْ ‏)‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَرَوَى شُعَيْبُ بْنُ أَبِي حَمْزَةَ عَنِ الزُّهْرِيِّ عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ عَنِ الزُّبَيْرِ وَلَمْ يَذْكُرْ فِيهِ عَنْ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ ‏.‏ وَرَوَاهُ عَبْدُ اللَّهِ بْنُ وَهْبٍ عَنِ اللَّيْثِ وَيُونُسَ عَنِ الزُّهْرِيِّ عَنْ عُرْوَةَ عَنْ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ نَحْوَ الْحَدِيثِ الأَوَّلِ ‏.‏\hadithno{1363}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated 'Abdullah bin Az-Zubair:"A man from the Ansar disputed with Az-Zubair before the Messenger of Allah (ﷺ) about the canals of Harrah which they used to irrigate the date palms. The Ansari said: 'Let the water pass'. But he refused, So they brought their dispute to the Messenger of Allah (ﷺ). The Messenger of Allah (ﷺ) said to Az-Zubair: 'O Zubair! Irrigate (your land) then let the water pass to you neighbor.' The Ansari became angry and said:'[O Messenger of Allah!] Is this because he is your aunt's son?' The face of the Messenger of Allah (ﷺ) changed color. Then he said: 'O Zubair! Irrigate (your land) and then withhold the water until it reaches the walls.' Az-Zubair said: 'By Allah! I think that this Ayah was revealed about that: But no, by your Lord, they can have no Faith until they make you (O Muhammad) judge in all disputes between them, and find in themselves no resistance against your decisions and accept (them) with full submission}}
\hadithdefcmd{tirmidhi}{1364}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي الْمُهَلَّبِ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، أَنَّ رَجُلاً، مِنَ الأَنْصَارِ أَعْتَقَ سِتَّةَ أَعْبُدٍ لَهُ عِنْدَ مَوْتِهِ وَلَمْ يَكُنْ لَهُ مَالٌ غَيْرُهُمْ فَبَلغَ ذَلِكَ النَّبِيَّ صلى الله عليه وسلم فَقَالَ لَهُ قَوْلاً شَدِيدًا ثُمَّ دَعَاهُمْ فَجَزَّأَهُمْ ثُمَّ أَقْرَعَ بَيْنَهُمْ فَأَعْتَقَ اثْنَيْنِ وَأَرَقَّ أَرْبَعَةً ‏.‏ وَقَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ عَنْ عِمْرَانَ بْنِ حُصَيْنٍ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عِمْرَانَ بْنِ حُصَيْنٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ وَهُوَ قَوْلُ مَالِكٍ وَالشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ يَرَوْنَ اسْتِعْمَالَ الْقُرْعَةِ فِي هَذَا وَفِي غَيْرِهِ ‏.‏ وَأَمَّا بَعْضُ أَهْلِ الْعِلْمِ مِنْ أَهْلِ الْكُوفَةِ وَغَيْرِهِمْ فَلَمْ يَرَوُا الْقُرْعَةَ وَقَالُوا يُعْتَقُ مِنْ كُلِّ عَبْدٍ الثُّلُثُ وَيُسْتَسْعَى فِي ثُلُثَىْ قِيمَتِهِ ‏.‏ وَأَبُو الْمُهَلَّبِ اسْمُهُ عَبْدُ الرَّحْمَنِ بْنُ عَمْرٍو الْجَرْمِيُّ وَهُوَ غَيْرُ أَبِي قِلاَبَةَ وَيُقَالُ مُعَاوِيَةُ بْنُ عَمْرٍو ‏.‏ وَأَبُو قِلاَبَةَ الْجَرْمِيُّ اسْمُهُ عَبْدُ اللَّهِ بْنُ زَيْدٍ ‏.‏\hadithno{1364}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated 'Imran bin Husain:"A Man from the Ansar freed six slaves of his upon his death, and he did not have any wealth aside from them. That was conveyed to the Prophet (ﷺ), and he said some harsh words about him." He said: "Then he called for them and he divided them and had them draw lots. So he freed two of them and left four as slaves}}
\hadithdefcmd{tirmidhi}{1365}{\hadithno{1365}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan}\hadithtrans{}}
\hadithdefcmd{tirmidhi}{1366}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا شَرِيكُ بْنُ عَبْدِ اللَّهِ النَّخَعِيُّ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَطَاءٍ، عَنْ رَافِعِ بْنِ خَدِيجٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ زَرَعَ فِي أَرْضِ قَوْمٍ بِغَيْرِ إِذْنِهِمْ فَلَيْسَ لَهُ مِنَ الزَّرْعِ شَيْءٌ وَلَهُ نَفَقَتُهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ مِنْ حَدِيثِ أَبِي إِسْحَاقَ إِلاَّ مِنْ هَذَا الْوَجْهِ مِنْ حَدِيثِ شَرِيكِ بْنِ عَبْدِ اللَّهِ ‏.‏ وَالْعَمَلُ عَلَى هَذَا الْحَدِيثِ عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ وَهُوَ قَوْلُ أَحْمَدَ وَإِسْحَاقَ ‏.‏ وَسَأَلْتُ مُحَمَّدَ بْنَ إِسْمَاعِيلَ عَنْ هَذَا الْحَدِيثِ فَقَالَ هُوَ حَدِيثٌ حَسَنٌ ‏.‏ وَقَالَ لاَ أَعْرِفُهُ مِنْ حَدِيثِ أَبِي إِسْحَاقَ إِلاَّ مِنْ رِوَايَةِ شَرِيكٍ ‏.‏ قَالَ مُحَمَّدٌ حَدَّثَنَا مَعْقِلُ بْنُ مَالِكٍ الْبَصْرِيُّ، حَدَّثَنَا عُقْبَةُ بْنُ الأَصَمِّ، عَنْ عَطَاءٍ، عَنْ رَافِعِ بْنِ خَدِيجٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏\hadithno{1366}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Rafi' bin Khadij:that the Prophet (ﷺ) said: "Whoever farms a people's land without their permission, then nothing he farms belongs to him and its finances are due to him}}
\hadithdefcmd{tirmidhi}{1367}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، وَسَعِيدُ بْنُ عَبْدِ الرَّحْمَنِ الْمَخْزُومِيُّ الْمَعْنَى الْوَاحِدُ، قَالاَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، وَعَنْ مُحَمَّدِ بْنِ النُّعْمَانِ بْنِ بَشِيرٍ، يُحَدِّثَانِ عَنِ النُّعْمَانِ بْنِ بَشِيرٍ، أَنَّ أَبَاهُ، نَحَلَ ابْنًا لَهُ غُلاَمًا فَأَتَى النَّبِيَّ صلى الله عليه وسلم يُشْهِدُهُ فَقَالَ ‏"‏ أَكُلَّ وَلَدِكَ نَحَلْتَهُ مِثْلَ مَا نَحَلْتَ هَذَا ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ فَارْدُدْهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ وَقَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ عَنِ النُّعْمَانِ بْنِ بَشِيرٍ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ يَسْتَحِبُّونَ التَّسْوِيَةَ بَيْنَ الْوَلَدِ حَتَّى قَالَ بَعْضُهُمْ يُسَوِّي بَيْنَ وَلَدِهِ حَتَّى فِي الْقُبْلَةِ ‏.‏ وَقَالَ بَعْضُهُمْ يُسَوِّي بَيْنَ وَلَدِهِ فِي النُّحْلِ وَالْعَطِيَّةِ الذَّكَرُ وَالأُنْثَى سَوَاءٌ ‏.‏ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ ‏.‏ وَقَالَ بَعْضُهُمُ التَّسْوِيَةُ بَيْنَ الْوَلَدِ أَنْ يُعْطَى الذَّكَرُ مِثْلَ حَظِّ الأُنْثَيَيْنِ مِثْلَ قِسْمَةِ الْمِيرَاثِ ‏.‏ وَهُوَ قَوْلُ أَحْمَدَ وَإِسْحَاقَ ‏.‏\hadithno{1367}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated An-Nu'man bin Bashir:That his father gave a slave to a son of his. So he went to the Prophet (ﷺ) to have him witness it. He (ﷺ) said: 'Have you given a gift similar to this one to all of your sons?' He replied: 'No'. So he said: 'Then take him back}}
\hadithdefcmd{tirmidhi}{1368}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ سَمُرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ جَارُ الدَّارِ أَحَقُّ بِالدَّارِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ الشَّرِيدِ وَأَبِي رَافِعٍ وَأَنَسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ سَمُرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَرَوَى عِيسَى بْنُ يُونُسَ عَنْ سَعِيدِ بْنِ أَبِي عَرُوبَةَ عَنْ قَتَادَةَ عَنْ أَنَسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَهُ ‏.‏ وَرُوِيَ عَنْ سَعِيدٍ عَنْ قَتَادَةَ عَنِ الْحَسَنِ عَنْ سَمُرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَالصَّحِيحُ عِنْدَ أَهْلِ الْعِلْمِ حَدِيثُ الْحَسَنِ عَنْ سَمُرَةَ وَلاَ نَعْرِفُ حَدِيثَ قَتَادَةَ عَنْ أَنَسٍ إِلاَّ مِنْ حَدِيثِ عِيسَى بْنِ يُونُسَ ‏.‏ وَحَدِيثُ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ الطَّائِفِيِّ عَنْ عَمْرِو بْنِ الشَّرِيدِ عَنْ أَبِيهِ عَنِ النَّبِيِّ صلى الله عليه وسلم فِي هَذَا الْبَابِ هُوَ حَدِيثٌ حَسَنٌ ‏.‏ وَرَوَى إِبْرَاهِيمُ بْنُ مَيْسَرَةَ عَنْ عَمْرِو بْنِ الشَّرِيدِ عَنْ أَبِي رَافِعٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ قَالَ سَمِعْتُ مُحَمَّدًا يَقُولُ كِلاَ الْحَدِيثَيْنِ عِنْدِي صَحِيحٌ ‏.‏\hadithno{1368}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Samurah:that the Messenger of Allah (ﷺ) said: "The neighbor of a home has more right to the home}}
\hadithdefcmd{tirmidhi}{1369}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا خَالِدُ بْنُ عَبْدِ اللَّهِ الْوَاسِطِيُّ، عَنْ عَبْدِ الْمَلِكِ بْنِ أَبِي سُلَيْمَانَ، عَنْ عَطَاءٍ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْجَارُ أَحَقُّ بِشُفْعَتِهِ يُنْتَظَرُ بِهِ وَإِنْ كَانَ غَائِبًا إِذَا كَانَ طَرِيقُهُمَا وَاحِدًا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ وَلاَ نَعْلَمُ أَحَدًا رَوَى هَذَا الْحَدِيثَ غَيْرَ عَبْدِ الْمَلِكِ بْنِ أَبِي سُلَيْمَانَ عَنْ عَطَاءٍ عَنْ جَابِرٍ ‏.‏ وَقَدْ تَكَلَّمَ شُعْبَةُ فِي عَبْدِ الْمَلِكِ بْنِ أَبِي سُلَيْمَانَ مِنْ أَجْلِ هَذَا الْحَدِيثِ وَعَبْدُ الْمَلِكِ هُوَ ثِقَةٌ مَأْمُونٌ عِنْدَ أَهْلِ الْحَدِيثِ لاَ نَعْلَمُ أَحَدًا تَكَلَّمَ فِيهِ غَيْرَ شُعْبَةَ مِنْ أَجْلِ هَذَا الْحَدِيثِ ‏.‏ وَقَدْ رَوَى وَكِيعٌ عَنْ شُعْبَةَ عَنْ عَبْدِ الْمَلِكِ بْنِ أَبِي سُلَيْمَانَ هَذَا الْحَدِيثَ ‏.‏ وَرُوِيَ عَنِ ابْنِ الْمُبَارَكِ عَنْ سُفْيَانَ الثَّوْرِيِّ قَالَ عَبْدُ الْمَلِكِ بْنُ أَبِي سُلَيْمَانَ مِيزَانٌ ‏.‏ يَعْنِي فِي الْعِلْمِ ‏.‏ وَالْعَمَلُ عَلَى هَذَا الْحَدِيثِ عِنْدَ أَهْلِ الْعِلْمِ أَنَّ الرَّجُلَ أَحَقُّ بِشُفْعَتِهِ وَإِنْ كَانَ غَائِبًا فَإِذَا قَدِمَ فَلَهُ الشُّفْعَةُ وَإِنْ تَطَاوَلَ ذَلِكَ ‏.‏\hadithno{1369}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Jabir:that the Messenger of Allah (ﷺ) said: "The neighbor has more right to his preemption. He is to be waited for even if he is absent, when their paths are the same}}
\hadithdefcmd{tirmidhi}{1370}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِذَا وَقَعَتِ الْحُدُودُ وَصُرِّفَتِ الطُّرُقُ فَلاَ شُفْعَةَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رَوَاهُ بَعْضُهُمْ مُرْسَلاً عَنْ أَبِي سَلَمَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم مِنْهُمْ عُمَرُ بْنُ الْخَطَّابِ وَعُثْمَانُ بْنُ عَفَّانَ وَبِهِ يَقُولُ بَعْضُ فُقَهَاءِ التَّابِعِينَ مِثْلُ عُمَرَ بْنِ عَبْدِ الْعَزِيزِ وَغَيْرِهِ وَهُوَ قَوْلُ أَهْلِ الْمَدِينَةِ مِنْهُمْ يَحْيَى بْنُ سَعِيدٍ الأَنْصَارِيُّ وَرَبِيعَةُ بْنُ أَبِي عَبْدِ الرَّحْمَنِ وَمَالِكُ بْنُ أَنَسٍ وَبِهِ يَقُولُ الشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ لاَ يَرَوْنَ الشُّفْعَةَ إِلاَّ لِلْخَلِيطِ وَلاَ يَرَوْنَ لِلْجَارِ شُفْعَةً إِذَا لَمْ يَكُنْ خَلِيطًا ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمُ الشُّفْعَةُ لِلْجَارِ ‏.‏ وَاحْتَجُّوا بِالْحَدِيثِ الْمَرْفُوعِ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ جَارُ الدَّارِ أَحَقُّ بِالدَّارِ ‏"‏ ‏.‏ وَقَالَ ‏"‏ الْجَارُ أَحَقُّ بِسَقَبِهِ ‏"‏ ‏.‏ وَهُوَ قَوْلُ الثَّوْرِيِّ وَابْنِ الْمُبَارَكِ وَأَهْلِ الْكُوفَةِ ‏.‏\hadithno{1370}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Narrated Jabir bin 'Abdullah:that the Messenger of Allah (ﷺ) said: "When the boundaries are defined and the streets are fixed, then there is no preemption}}
\hadithdefcmd{tirmidhi}{1371}{حَدَّثَنَا يُوسُفُ بْنُ عِيسَى، حَدَّثَنَا الْفَضْلُ بْنُ مُوسَى، عَنْ أَبِي حَمْزَةَ السُّكَّرِيِّ، عَنْ عَبْدِ الْعَزِيزِ بْنِ رُفَيْعٍ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الشَّرِيكُ شَفِيعٌ وَالشُّفْعَةُ فِي كُلِّ شَيْءٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ لاَ نَعْرِفُهُ مِثْلَ هَذَا إِلاَّ مِنْ حَدِيثِ أَبِي حَمْزَةَ السُّكَّرِيِّ ‏.‏ وَقَدْ رَوَى غَيْرُ وَاحِدٍ هَذَا الْحَدِيثَ عَنْ عَبْدِ الْعَزِيزِ بْنِ رُفَيْعٍ عَنِ ابْنِ أَبِي مُلَيْكَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم مُرْسَلاً وَهَذَا أَصَحُّ ‏.‏ حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، عَنْ عَبْدِ الْعَزِيزِ بْنِ رُفَيْعٍ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ بِمَعْنَاهُ وَلَيْسَ فِيهِ عَنِ ابْنِ عَبَّاسٍ وَهَكَذَا رَوَى غَيْرُ وَاحِدٍ عَنْ عَبْدِ الْعَزِيزِ بْنِ رُفَيْعٍ مِثْلَ هَذَا لَيْسَ فِيهِ عَنِ ابْنِ عَبَّاسٍ وَهَذَا أَصَحُّ مِنْ حَدِيثِ أَبِي حَمْزَةَ ‏.‏ وَأَبُو حَمْزَةَ ثِقَةٌ يُمْكِنُ أَنْ يَكُونَ الْخَطَأُ مِنْ غَيْرِ أَبِي حَمْزَةَ ‏.‏ حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ عَبْدِ الْعَزِيزِ بْنِ رُفَيْعٍ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَ حَدِيثِ أَبِي بَكْرِ بْنِ عَيَّاشٍ ‏.‏ وَقَالَ أَكْثَرُ أَهْلِ الْعِلْمِ إِنَّمَا تَكُونُ الشُّفْعَةُ فِي الدُّورِ وَالأَرَضِينَ وَلَمْ يَرَوُا الشُّفْعَةَ فِي كُلِّ شَيْءٍ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ الشُّفْعَةُ فِي كُلِّ شَيْءٍ ‏.‏ وَالْقَوْلُ الأَوَّلُ أَصَحُّ ‏.‏\hadithno{1371}\hadithgrade{Ahmad Muhammad Shakir: Daif Munkar; Al-Albani: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Ibn Abbas:that the Messenger of Allah (ﷺ) said: "The partner is the preemptor, and preemption is in everything}}
\hadithdefcmd{tirmidhi}{1372}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنْ رَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ يَزِيدَ، مَوْلَى الْمُنْبَعِثِ عَنْ زَيْدِ بْنِ خَالِدٍ الْجُهَنِيِّ، أَنَّ رَجُلاً، سَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ اللُّقَطَةِ فَقَالَ ‏"‏ عَرِّفْهَا سَنَةً ثُمَّ اعْرِفْ وِكَاءَهَا وَوِعَاءَهَا وَعِفَاصَهَا ثُمَّ اسْتَنْفِقْ بِهَا فَإِنْ جَاءَ رَبُّهَا فَأَدِّهَا إِلَيْهِ ‏"‏ ‏.‏ فَقَالَ لَهُ يَا رَسُولَ اللَّهِ فَضَالَّةُ الْغَنَمِ فَقَالَ ‏"‏ خُذْهَا فَإِنَّمَا هِيَ لَكَ أَوْ لأَخِيكَ أَوْ لِلذِّئْبِ ‏"‏ ‏.‏ فَقَالَ يَا رَسُولَ اللَّهِ فَضَالَّةُ الإِبِلِ قَالَ فَغَضِبَ النَّبِيُّ صلى الله عليه وسلم حَتَّى احْمَرَّتْ وَجْنَتَاهُ أَوِ احْمَرَّ وَجْهُهُ فَقَالَ ‏"‏ مَا لَكَ وَلَهَا مَعَهَا حِذَاؤُهَا وَسِقَاؤُهَا حَتَّى تَلْقَى رَبَّهَا ‏"‏ ‏.‏ حَدِيثُ زَيْدِ بْنِ خَالِدٍ حَدِيثٌ حَسَنٌ صَحِيحٌ وَقَدْ رُوِيَ عَنْهُ مِنْ غَيْرِ وَجْهٍ ‏.‏ وَحَدِيثُ يَزِيدَ مَوْلَى الْمُنْبَعِثِ عَنْ زَيْدِ بْنِ خَالِدٍ حَدِيثٌ حَسَنٌ صَحِيحٌ وَقَدْ رُوِيَ عَنْهُ مِنْ غَيْرِ وَجْهٍ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أُبَىِّ بْنِ كَعْبٍ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو وَالْجَارُودِ بْنِ الْمُعَلَّى وَعِيَاضِ بْنِ حِمَارٍ وَجَرِيرِ بْنِ عَبْدِ اللَّهِ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ وَرَخَّصُوا فِي اللُّقَطَةِ إِذَا عَرَّفَهَا سَنَةً فَلَمْ يَجِدْ مَنْ يَعْرِفُهَا أَنْ يَنْتَفِعَ بِهَا ‏.‏ وَهُوَ قَوْلُ الشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ يُعَرِّفُهَا سَنَةً فَإِنْ جَاءَ صَاحِبُهَا وَإِلاَّ تَصَدَّقَ بِهَا ‏.‏ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَعَبْدِ اللَّهِ بْنِ الْمُبَارَكِ وَهُوَ قَوْلُ أَهْلِ الْكُوفَةِ لَمْ يَرَوْا لِصَاحِبِ اللُّقَطَةِ أَنْ يَنْتَفِعَ بِهَا إِذَا كَانَ غَنِيًّا ‏.‏ وَقَالَ الشَّافِعِيُّ يَنْتَفِعُ بِهَا وَإِنْ كَانَ غَنِيًّا لأَنَّ أُبَىَّ بْنَ كَعْبٍ أَصَابَ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم صُرَّةً فِيهَا مِائَةُ دِينَارٍ فَأَمَرَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يُعَرِّفَهَا ثُمَّ يَنْتَفِعَ بِهَا وَكَانَ أُبَىٌّ كَثِيرَ الْمَالِ مِنْ مَيَاسِيرِ أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَمَرَهُ النَّبِيُّ صلى الله عليه وسلم أَنْ يُعَرِّفَهَا فَلَمْ يَجِدْ مَنْ يَعْرِفُهَا فَأَمَرَهُ النَّبِيُّ صلى الله عليه وسلم أَنْ يَأْكُلَهَا فَلَوْ كَانَتِ اللُّقَطَةُ لَمْ تَحِلَّ إِلاَّ لِمَنْ تَحِلُّ لَهُ الصَّدَقَةُ لَمْ تَحِلَّ لِعَلِيِّ بْنِ أَبِي طَالِبٍ لأَنَّ عَلِيَّ بْنَ أَبِي طَالِبٍ أَصَابَ دِينَارًا عَلَى عَهْدِ النَّبِيِّ صلى الله عليه وسلم فَعَرَّفَهُ فَلَمْ يَجِدْ مَنْ يَعْرِفُهُ فَأَمَرَهُ النَّبِيُّ صلى الله عليه وسلم بِأَكْلِهِ وَكَانَ لاَ يَحِلُّ لَهُ الصَّدَقَةُ ‏.‏ وَقَدْ رَخَّصَ بَعْضُ أَهْلِ الْعِلْمِ إِذَا كَانَتِ اللُّقَطَةُ يَسِيرَةً أَنْ يَنْتَفِعَ بِهَا وَلاَ يُعَرِّفَهَا ‏.‏ وَقَالَ بَعْضُهُمْ إِذَا كَانَ دُونَ دِينَارٍ يُعَرِّفُهَا قَدْرَ جُمُعَةٍ ‏.‏ وَهُوَ قَوْلُ إِسْحَاقَ بْنِ إِبْرَاهِيمَ ‏.‏\hadithno{1372}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Zaid bin Khalid Al-Juhni:"A man asked the Messenger of Allah (ﷺ) about lost items. So he said: 'Make a public announcement about it for one year. Remember its string, its contained, and its sack. Then use it, and if its owner comes then give it to him.' So he said to him: 'O Messenger of Allah! What about the stray sheep?' He said:'Take it, for it is either for you, your brother, or the wolf.' He said: 'O Messenger of Allah! What about stray camel?'" He said: "Then the Prophet (ﷺ) got angry until his cheeks became red or his face became red. He said: 'What concern is it of yours? It has its feet and its water reserve until it reaches its owner}}
\hadithdefcmd{tirmidhi}{1373}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو بَكْرٍ الْحَنَفِيُّ، أَخْبَرَنَا الضَّحَّاكُ بْنُ عُثْمَانَ، حَدَّثَنِي سَالِمٌ أَبُو النَّضْرِ، عَنْ بُسْرِ بْنِ سَعِيدٍ، عَنْ زَيْدِ بْنِ خَالِدٍ الْجُهَنِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم سُئِلَ عَنِ اللُّقَطَةِ فَقَالَ ‏ "‏ عَرِّفْهَا سَنَةً فَإِنِ اعْتُرِفَتْ فَأَدِّهَا وَإِلاَّ فَاعْرِفْ وِعَاءَهَا وَعِفَاصَهَا وَوِكَاءَهَا وَعَدَدَهَا ثُمَّ كُلْهَا فَإِذَا جَاءَ صَاحِبُهَا فَأَدِّهَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ زَيْدِ بْنِ خَالِدٍ حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ قَالَ أَحْمَدُ أَصَحُّ شَيْءٍ فِي هَذَا الْبَابِ هَذَا الْحَدِيثُ ‏.‏\hadithno{1373}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih}\hadithtrans{Zaid bin Khalid Al-Juhni narrated that the Messenger of Allah (ﷺ) was asked about the lost item. He said:"Make a public announcement about it for one year, if it is claimed then give it to him. Otherwise remember its sack, string, and its count. Then use it, and if its owner comes, give it to him}}
\hadithdefcmd{tirmidhi}{1374}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، وَيَزِيدُ بْنُ هَارُونَ، عَنْ سُفْيَانَ الثَّوْرِيِّ، عَنْ سَلَمَةَ بْنِ كُهَيْلٍ، عَنْ سُوَيْدِ بْنِ غَفَلَةَ، قَالَ خَرَجْتُ مَعَ زَيْدِ بْنِ صُوحَانَ وَسَلْمَانَ بْنِ رَبِيعَةَ فَوَجَدْتُ سَوْطًا قَالَ ابْنُ نُمَيْرٍ فِي حَدِيثِهِ فَالْتَقَطْتُ سَوْطًا فَأَخَذْتُهُ قَالاَ دَعْهُ ‏.‏ فَقُلْتُ لاَ أَدَعُهُ تَأْكُلُهُ السِّبَاعُ لآخُذَنَّهُ فَلأَسْتَمْتِعَنَّ بِهِ ‏.‏ فَقَدِمْتُ عَلَى أُبَىِّ بْنِ كَعْبٍ فَسَأَلْتُهُ عَنْ ذَلِكَ وَحَدَّثْتُهُ الْحَدِيثَ فَقَالَ أَحْسَنْتَ أَنَا وَجَدْتُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم صُرَّةً فِيهَا مِائَةُ دِينَارٍ ‏.‏ قَالَ فَأَتَيْتُهُ بِهَا فَقَالَ لِي ‏"‏ عَرِّفْهَا حَوْلاً ‏"‏ ‏.‏ فَعَرَّفْتُهَا حَوْلاً فَمَا أَجِدُ مَنْ يَعْرِفُهَا ثُمَّ أَتَيْتُهُ بِهَا فَقَالَ ‏"‏ عَرِّفْهَا حَوْلاً آخَرَ ‏"‏ ‏.‏ فَعَرَّفْتُهَا ثُمَّ أَتَيْتُهُ بِهَا فَقَالَ ‏"‏ عَرِّفْهَا حَوْلاً آخَرَ ‏"‏ ‏.‏ وَقَالَ ‏"‏ أَحْصِ عِدَّتَهَا وَوِعَاءَهَا وَوِكَاءَهَا فَإِنْ جَاءَ طَالِبُهَا فَأَخْبَرَكَ بِعِدَّتِهَا وَوِعَائِهَا وَوِكَائِهَا فَادْفَعْهَا إِلَيْهِ وَإِلاَّ فَاسْتَمْتِعْ بِهَا ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1374}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Suwaid bin Ghafalah said:"I went out with Zaid bin Suhan and Salman bin Rabi'ah, and found a whip." In his narration Ibn Numair (one of the narrators) said: "I found a lost whip and took it. They said: 'Leave it'. I said: 'I will not leave it to be eaten by predators. I will take it to make use of it.' So I met up with Ubayy bin Ka'b and asked him about that. So he narrated the Hadith, he said: 'That is fine. I found a sack containing one hundred Dinar during the lifetime of the Messenger of Allah (ﷺ)' He said: 'So I brought it to him. He said to me: "Make a public announcement about it for one year." So I announced it for a year but did not find anyone to claim it. Then I brought it to him. He said to me: "Make a public announcement about it for another year." So I announced it for a year but did not find anyone to claim it. Then I brought it to him. He said: "Make a public announcement about if for another year." And he said: "Remember its amount, its container and its string. If someone comes seeking it and informs you of its amount and its string, then give it to him, otherwise use it}}
\hadithdefcmd{tirmidhi}{1375}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَنْبَأَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنِ ابْنِ عَوْنٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ أَصَابَ عُمَرُ أَرْضًا بِخَيْبَرَ فَقَالَ يَا رَسُولَ اللَّهِ أَصَبْتُ مَالاً بِخَيْبَرَ لَمْ أُصِبْ مَالاً قَطُّ أَنْفَسَ عِنْدِي مِنْهُ فَمَا تَأْمُرُنِي قَالَ ‏ "‏ إِنْ شِئْتَ حَبَسْتَ أَصْلَهَا وَتَصَدَّقْتَ بِهَا ‏"‏ ‏.‏ فَتَصَدَّقَ بِهَا عُمَرُ أَنَّهَا لاَ يُبَاعُ أَصْلُهَا وَلاَ يُوهَبُ وَلاَ يُورَثُ تَصَدَّقَ بِهَا فِي الْفُقَرَاءِ وَالْقُرْبَى وَفِي الرِّقَابِ وَفِي سَبِيلِ اللَّهِ وَابْنِ السَّبِيلِ وَالضَّيْفِ لاَ جُنَاحَ عَلَى مَنْ وَلِيَهَا أَنْ يَأْكُلَ مِنْهَا بِالْمَعْرُوفِ أَوْ يُطْعِمَ صَدِيقًا غَيْرَ مُتَمَوِّلٍ فِيهِ ‏.‏ قَالَ فَذَكَرْتُهُ لِمُحَمَّدِ بْنِ سِيرِينَ فَقَالَ غَيْرَ مُتَأَثِّلٍ مَالاً ‏.‏ قَالَ ابْنُ عَوْنٍ فَحَدَّثَنِي بِهِ رَجُلٌ آخَرُ أَنَّهُ قَرَأَهَا فِي قِطْعَةِ أَدِيمٍ أَحْمَرَ غَيْرَ مُتَأَثِّلٍ مَالاً ‏.‏ قَالَ إِسْمَاعِيلُ وَأَنَا قَرَأْتُهَا عِنْدَ ابْنِ عُبَيْدِ اللَّهِ بْنِ عُمَرَ فَكَانَ فِيهِ غَيْرَ مُتَأَثِّلٍ مَالاً ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ لاَ نَعْلَمُ بَيْنَ الْمُتَقَدِّمِينَ مِنْهُمْ فِي ذَلِكَ اخْتِلاَفًا فِي إِجَازَةِ وَقْفِ الأَرَضِينَ وَغَيْرِ ذَلِكَ ‏.‏\hadithno{1375}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Isma'il bin Ibrahim from Ibn 'Awn, from Nafi' that Ibn 'Umar said:"Umar got some land from Khaibar and said: 'O Messenger of Allah! I got some wealth from Khaibar and I never ever had any wealth as plentiful as it, so what do you order me (to do with it)?' He said: 'If you wish, make it a grant and give charity from it.' So 'Umar gave it in charity: That is not to be sold entirely, nor given away, nor inherited, to be used to produce charity for the needy, those who are near it, for freeing slaves, for the cause of Allah, the wayfarer, the guest, and that there is no harm on its custodian consuming what is customary from it, or eating from its charity, without trying to amass wealth from it}}
\hadithdefcmd{tirmidhi}{1376}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، رضى الله عنه أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا مَاتَ الإِنْسَانُ انْقَطَعَ عَمَلُهُ إِلاَّ مِنْ ثَلاَثٍ صَدَقَةٌ جَارِيَةٌ وَعِلْمٌ يُنْتَفَعُ بِهِ وَوَلَدٌ صَالِحٌ يَدْعُو لَهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1376}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Hurairah, may Allah be pleased with him, narrated that the Messenger of Allah (ﷺ) said:"When a person dies, his deeds are cut off except for three: Continuing charity, knowledge that others benefited from, and a righteous son who supplicates for him}}
\hadithdefcmd{tirmidhi}{1377}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ الْعَجْمَاءُ جُرْحُهَا جُبَارٌ وَالْبِئْرُ جُبَارٌ وَالْمَعْدِنُ جُبَارٌ وَفِي الرِّكَازِ الْخُمُسُ ‏"‏ ‏.‏ حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، وَأَبِي، سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ جَابِرٍ وَعَمْرِو بْنِ عَوْفٍ الْمُزَنِيِّ وَعُبَادَةَ بْنِ الصَّامِتِ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ حَدَّثَنَا الأَنْصَارِيُّ حَدَّثَنَا مَعْنٌ قَالَ أَخْبَرَنَا مَالِكُ بْنُ أَنَسٍ وَتَفْسِيرُ حَدِيثِ النَّبِيِّ صلى الله عليه وسلم ‏"‏ الْعَجْمَاءُ جُرْحُهَا جُبَارٌ ‏"‏ ‏.‏ يَقُولُ هَدَرٌ لاَ دِيَةَ فِيهِ ‏.‏ قَالَ أَبُو عِيسَى وَمَعْنَى قَوْلِهِ ‏"‏ الْعَجْمَاءُ جُرْحُهَا جُبَارٌ ‏"‏ ‏.‏ فَسَّرَ ذَلِكَ بَعْضُ أَهْلِ الْعِلْمِ قَالُوا الْعَجْمَاءُ الدَّابَّةُ الْمُنْفَلِتَةُ مِنْ صَاحِبِهَا فَمَا أَصَابَتْ فِي انْفِلاَتِهَا فَلاَ غُرْمَ عَلَى صَاحِبِهَا ‏.‏ ‏"‏ وَالْمَعْدِنُ جُبَارٌ ‏"‏ ‏.‏ يَقُولُ إِذَا احْتَفَرَ الرَّجُلُ مَعْدِنًا فَوَقَعَ فِيهَا إِنْسَانٌ فَلاَ غُرْمَ عَلَيْهِ وَكَذَلِكَ الْبِئْرُ إِذَا احْتَفَرَهَا الرَّجُلُ لِلسَّبِيلِ فَوَقَعَ فِيهَا إِنْسَانٌ فَلاَ غُرْمَ عَلَى صَاحِبِهَا ‏.‏ ‏"‏ وَفِي الرِّكَازِ الْخُمُسُ ‏"‏ ‏.‏ وَالرِّكَازُ مَا وُجِدَ فِي دَفْنِ أَهْلِ الْجَاهِلِيَّةِ ‏.‏ فَمَنْ وَجَدَ رِكَازًا أَدَّى مِنْهُ الْخُمُسَ إِلَى السُّلْطَانِ وَمَا بَقِيَ فَهُوَ لَهُ ‏.‏\hadithno{1377}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Abu Hurairah:that the Messenger of Allah (ﷺ) said: "The injuries caused by the animal are without liability, and wells are without liability, and mines are without liability, and the Khumus is due on Rikaz." (Another Chain) from Abu Hurairah, from the Prophet (ﷺ) with similar meaning}}
\hadithdefcmd{tirmidhi}{1378}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، أَخْبَرَنَا عَبْدُ الْوَهَّابِ الثَّقَفِيُّ، أَخْبَرَنَا أَيُّوبُ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ سَعِيدِ بْنِ زَيْدٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ أَحْيَى أَرْضًا مَيِّتَةً فَهِيَ لَهُ وَلَيْسَ لِعِرْقِ ظَالِمٍ حَقٌّ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَقَدْ رَوَاهُ بَعْضُهُمْ عَنْ هِشَامِ بْنِ عُرْوَةَ عَنْ أَبِيهِ عَنِ النَّبِيِّ صلى الله عليه وسلم مُرْسَلاً ‏.‏ وَالْعَمَلُ عَلَى هَذَا الْحَدِيثِ عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ وَهُوَ قَوْلُ أَحْمَدَ وَإِسْحَاقَ قَالُوا لَهُ أَنْ يُحْيِيَ الأَرْضَ الْمَوَاتَ بِغَيْرِ إِذْنِ السُّلْطَانِ ‏.‏ وَقَدْ قَالَ بَعْضُهُمْ لَيْسَ لَهُ أَنْ يُحْيِيَهَا إِلاَّ بِإِذْنِ السُّلْطَانِ ‏.‏ وَالْقَوْلُ الأَوَّلُ أَصَحُّ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ جَابِرٍ وَعَمْرِو بْنِ عَوْفٍ الْمُزَنِيِّ جَدِّ كَثِيرٍ وَسَمُرَةَ ‏.‏ حَدَّثَنَا أَبُو مُوسَى مُحَمَّدُ بْنُ الْمُثَنَّى قَالَ سَأَلْتُ أَبَا الْوَلِيدِ الطَّيَالِسِيَّ عَنْ قَوْلِهِ ‏"‏ وَلَيْسَ لِعِرْقِ ظَالِمٍ حَقٌّ ‏"‏ ‏.‏ فَقَالَ الْعِرْقُ الظَّالِمُ الْغَاصِبُ الَّذِي يَأْخُذُ مَا لَيْسَ لَهُ ‏.‏ قُلْتُ هُوَ الرَّجُلُ الَّذِي يَغْرِسُ فِي أَرْضِ غَيْرِهِ قَالَ هُوَ ذَاكَ ‏.‏\hadithno{1378}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Daif; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Sa'eed bin Zaid:that the Prophet (ﷺ) said: "Whoever revives a barren land then it is for him, and there is no right for the unjust root}}
\hadithdefcmd{tirmidhi}{1379}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الْوَهَّابِ، حَدَّثَنَا أَيُّوبُ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ وَهْبِ بْنِ كَيْسَانَ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَحْيَا أَرْضًا مَيِّتَةً فَهِيَ لَهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1379}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Jabir bin 'Abdullah:that the Prophet (ﷺ) said: "Whoever revives a barren land, then it is for him}}
\hadithdefcmd{tirmidhi}{1380}{قَالَ قُلْتُ لِقُتَيْبَةَ بْنِ سَعِيدٍ حَدَّثَكُمْ مُحَمَّدُ بْنُ يَحْيَى بْنِ قَيْسٍ الْمَأْرِبِيُّ، حَدَّثَنِي أَبِي، عَنْ ثُمَامَةَ بْنِ شُرَاحِيلَ، عَنْ سُمَىِّ بْنِ قَيْسٍ، عَنْ شُمَيْرٍ، عَنْ أَبْيَضَ بْنِ حَمَّالٍ، أَنَّهُ وَفَدَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَاسْتَقْطَعَهُ الْمِلْحَ فَقَطَعَ لَهُ فَلَمَّا أَنْ وَلَّى قَالَ رَجُلٌ مِنَ الْمَجْلِسِ أَتَدْرِي مَا قَطَعْتَ لَهُ إِنَّمَا قَطَعْتَ لَهُ الْمَاءَ الْعِدَّ ‏.‏ قَالَ فَانْتَزَعَهُ مِنْهُ ‏.‏ قَالَ وَسَأَلَهُ عَمَّا يُحْمَى مِنَ الأَرَاكِ قَالَ ‏ "‏ مَا لَمْ تَنَلْهُ خِفَافُ الإِبِلِ ‏"‏ ‏.‏ فَأَقَرَّ بِهِ قُتَيْبَةُ وَقَالَ نَعَمْ ‏.‏ حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ قَيْسٍ الْمَأْرِبِيُّ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏ الْمَأْرِبُ نَاحِيَةٌ مِنَ الْيَمَنِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ وَائِلٍ وَأَسْمَاءَ بِنْتِ أَبِي بَكْرٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبْيَضَ بْنِ حَمَّالٍ حَدِيثٌ غَرِيبٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ فِي الْقَطَائِعِ يَرَوْنَ جَائِزًا أَنْ يُقْطِعَ الإِمَامُ لِمَنْ رَأَى ذَلِكَ ‏.‏\hadithno{1380}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Shumair:that Abyad bin Hammal visited the Messenger of Allah (ﷺ) who asked him to set aside a reserve of salt(a mine). So he reserved it for him. As he was turning away, a man in the gathering said: "Do you know what you reserved for him ? You merely reserved stagnant water for him." He (Shumair) said: "So he left him." He (Shumair) said: "So he asked him (the Prophet (ﷺ)) about making a private pasture of Arak (a type of tree)." He said: "As long as it is not harmed by the hooves of the camels." So I (At-Tirmidhi) recited that before Qutaibah and he said: "Yes". (Another chain) with similar meaning}}
\hadithdefcmd{tirmidhi}{1381}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو دَاوُدَ، أَخْبَرَنَا شُعْبَةُ، عَنْ سِمَاكٍ، قَالَ سَمِعْتُ عَلْقَمَةَ بْنَ وَائِلٍ، يُحَدِّثُ عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أَقْطَعَهُ أَرْضًا بِحَضْرَمَوْتَ ‏.‏ قَالَ مَحْمُودُ وَأَخْبَرَنَا النَّضْرُ، عَنْ شُعْبَةَ، وَزَادَ، فِيهِ وَبَعَثَ مَعَهُ مُعَاوِيَةَ لِيُقْطِعَهَا إِيَّاهُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1381}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Alqamah bin Wa'il:from his father that the Prophet (ﷺ) set aside a land reserve for him in Hadramawt. (One of the narrators added): "And he sent Mu'awiyah with him to reserve it for him}}
\hadithdefcmd{tirmidhi}{1382}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَا مِنْ مُسْلِمٍ يَغْرِسُ غَرْسًا أَوْ يَزْرَعُ زَرْعًا فَيَأْكُلُ مِنْهُ إِنْسَانٌ أَوْ طَيْرٌ أَوْ بَهِيمَةٌ إِلاَّ كَانَتْ لَهُ صَدَقَةٌ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي أَيُّوبَ وَجَابِرٍ وَأُمِّ مُبَشِّرٍ وَزَيْدِ بْنِ خَالِدٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَنَسٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1382}\hadithgrade{Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Anas:that the Prophet (ﷺ) said: "No Muslim plants a plant or sows a crop, then a person, or a bird, or an animal eats from it, except that it will be charity for him}}
\hadithdefcmd{tirmidhi}{1383}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم عَامَلَ أَهْلَ خَيْبَرَ بِشَطْرِ مَا يَخْرُجُ مِنْهَا مِنْ ثَمَرٍ أَوْ زَرْعٍ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَنَسٍ وَابْنِ عَبَّاسٍ وَزَيْدِ بْنِ ثَابِتٍ وَجَابِرٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ لَمْ يَرَوْا بِالْمُزَارَعَةِ بَأْسًا عَلَى النِّصْفِ وَالثُّلُثِ وَالرُّبُعِ ‏.‏ وَاخْتَارَ بَعْضُهُمْ أَنْ يَكُونَ الْبَذْرُ مِنْ رَبِّ الأَرْضِ ‏.‏ وَهُوَ قَوْلُ أَحْمَدَ وَإِسْحَاقَ ‏.‏ وَكَرِهَ بَعْضُ أَهْلِ الْعِلْمِ الْمُزَارَعَةَ بِالثُّلُثِ وَالرُّبُعِ وَلَمْ يَرَوْا بِمُسَاقَاةِ النَّخِيلِ بِالثُّلُثِ وَالرُّبُعِ بَأْسًا ‏.‏ وَهُوَ قَوْلُ مَالِكِ بْنِ أَنَسٍ وَالشَّافِعِيِّ ‏.‏ وَلَمْ يَرَ بَعْضُهُمْ أَنْ يَصِحَّ شَيْءٌ مِنَ الْمُزَارَعَةِ إِلاَّ أَنْ يَسْتَأْجِرَ الأَرْضَ بِالذَّهَبِ وَالْفِضَّةِ ‏.‏\hadithno{1383}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Ibn 'Umar:"The Prophet (ﷺ) made a deal with the people of Khaibar for half of what was produced from it, whether fruits or crops}}
\hadithdefcmd{tirmidhi}{1384}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، عَنْ أَبِي حَصِينٍ، عَنْ مُجَاهِدٍ، عَنْ رَافِعِ بْنِ خَدِيجٍ، قَالَ نَهَانَا رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ أَمْرٍ كَانَ لَنَا نَافِعًا إِذَا كَانَتْ لأَحَدِنَا أَرْضٌ أَنْ يُعْطِيَهَا بِبَعْضِ خَرَاجِهَا أَوْ بِدَرَاهِمَ وَقَالَ ‏ "‏ إِذَا كَانَتْ لأَحَدِكُمْ أَرْضٌ فَلْيَمْنَحْهَا أَخَاهُ أَوْ لِيَزْرَعْهَا ‏"‏ ‏.‏\hadithno{1384}\hadithgrade{Ahmad Muhammad Shakir: Shadh; Al-Albani: Shadh; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Rafi' bin Khadij:"The Messenger of Allah (ﷺ) forbade us from a matter that was of benefit for us. When one of us had some land and we would let someone use it for a portion of its produce or some Dirham. He said: 'When one of you has some land then let him grant it to his brother, or let him farm it}}
\hadithdefcmd{tirmidhi}{1385}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، أَخْبَرَنَا الْفَضْلُ بْنُ مُوسَى الشَّيْبَانِيُّ، أَخْبَرَنَا شَرِيكٌ، عَنْ شُعْبَةَ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَمْ يُحَرِّمِ الْمُزَارَعَةَ وَلَكِنْ أَمَرَ أَنْ يَرْفُقَ بَعْضُهُمْ بِبَعْضٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَحَدِيثُ رَافِعٍ فِيهِ اضْطِرَابٌ يُرْوَى هَذَا الْحَدِيثُ عَنْ رَافِعِ بْنِ خَدِيجٍ عَنْ عُمُومَتِهِ وَيُرْوَى عَنْهُ عَنْ ظُهَيْرِ بْنِ رَافِعٍ وَهُوَ أَحَدُ عُمُومَتِهِ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ عَنْهُ عَلَى رِوَايَاتٍ مُخْتَلِفَةٍ ‏.‏ وَفِي الْبَابِ عَنْ زَيْدِ بْنِ ثَابِتٍ وَجَابِرٍ رضى الله عنهما ‏.‏\hadithno{1385}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Ibn 'Abbas:"The Messenger of Allah (ﷺ) did not prohibit share-cropping. But he ordered that they be helpful with each other}}
